[telepathy-gabble/telepathy-gabble-0.8] Fall back to stun.telepathy.im not stun.ccu

Will Thompson will.thompson at collabora.co.uk
Mon Dec 7 06:43:24 PST 2009


---
 src/connection.h                    |    2 +-
 tests/twisted/jingle/stun-server.py |    4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/src/connection.h b/src/connection.h
index 0f7da11..b2a47d0 100644
--- a/src/connection.h
+++ b/src/connection.h
@@ -41,7 +41,7 @@ G_BEGIN_DECLS
 /* Default parameters for optional parameters */
 #define GABBLE_PARAMS_DEFAULT_HTTPS_PROXY_PORT           443
 #define GABBLE_PARAMS_DEFAULT_STUN_PORT                  3478
-#define GABBLE_PARAMS_DEFAULT_FALLBACK_STUN_SERVER       "stun.collabora.co.uk"
+#define GABBLE_PARAMS_DEFAULT_FALLBACK_STUN_SERVER       "stun.telepathy.im"
 #define GABBLE_PARAMS_DEFAULT_SOCKS5_PROXIES             { NULL }
 
 
diff --git a/tests/twisted/jingle/stun-server.py b/tests/twisted/jingle/stun-server.py
index c6831ea..52e8976 100644
--- a/tests/twisted/jingle/stun-server.py
+++ b/tests/twisted/jingle/stun-server.py
@@ -101,12 +101,12 @@ def test(q, bus, conn, stream,
 
     if expected_stun_server == None:
         # If there is no stun server set then gabble should fallback on the
         # default fallback stunserver (stun.collabora.co.uk)
         # This test assumes that if python can resolve the stun servers
         # address then gabble should be able to resolv it as well
         try:
             expected_stun_server = \
-                socket.gethostbyname("stun.collabora.co.uk")
+                socket.gethostbyname("stun.telepathy.im")
             expected_stun_port = 3478
         except:
             expected_stun_server = None
@@ -101,12 +101,12 @@ def test(q, bus, conn, stream,
     if expected_stun_server == None:
         # If there is no stun server set then gabble should fallback on the
-        # default fallback stunserver (stun.collabora.co.uk)
+        # default fallback stunserver (stun.telepathy.im)
         # This test assumes that if python can resolve the stun servers
         # address then gabble should be able to resolv it as well
-- 
1.5.6.5




More information about the telepathy-commits mailing list